@@ -20,10 +20,10 @@
  * clipboard_get_func - dummy get_func for gtk_clipboard_set_with_data ()
  */
 static void
-clipboard_get_func (GtkClipboard *clipboard __attribute__((__unused__)),
-		   GtkSelectionData *selection_data __attribute__((__unused__)),
-		    guint info __attribute__((__unused__)),
-		    gpointer user_data_or_owner __attribute__((__unused__)))
+clipboard_get_func (GtkClipboard *clipboard GNUC_UNUSED,
+		   GtkSelectionData *selection_data GNUC_UNUSED,
+		    guint info GNUC_UNUSED,
+		    gpointer user_data_or_owner GNUC_UNUSED)
 {
 }
 
@@ -31,8 +31,8 @@ clipboard_get_func (GtkClipboard *clipboard __attribute__((__unused__)),
  * clipboard_clear_func - dummy clear_func for gtk_clipboard_set_with_data ()
  */
 static void
-clipboard_clear_func (GtkClipboard *clipboard __attribute__((__unused__)),
-		      gpointer user_data_or_owner __attribute__((__unused__)))
+clipboard_clear_func (GtkClipboard *clipboard GNUC_UNUSED,
+		      gpointer user_data_or_owner GNUC_UNUSED)
 {
 }
 
